searchNodes=[{"doc":"A convenient interface to setting LEDs defined in /sys/class/leds.While an application could write directly to /sys/class/leds, the main advantage of using this module is to provide a layer of abstraction that allows easily defining application-specific led names and states, like this:alias Nerves.Leds Leds.set power: true # turn on the led we called &quot;power&quot; Leds.set power: :slowblink # make it blink slowly Leds.set connected: false, alert: :fastblink # set multiple LED states at once ## alternate syntax via set/2 Leds.set :power, :slowblink ConfigurationUse config.exs in your application to create a friendly name that maps to an entry in /sys/class/leds that make sense for your application.A trivial example for Raspberry Pi:# in your app&#39;s config/config.exs: config :nerves_leds, names: [ red: &quot;led0&quot;, green: &quot;led1&quot; ]A more useful example for the Alix 2D boards implementing a router:# in your app&#39;s config/config.exs: config :nerves_leds, names: [ power: &quot;alix:1&quot;, connected: &quot;alix:2&quot;, alert: &quot;alix:3&quot; ]Included statesIn addition to true (on) and false (off) the following atoms provide predefined behaviors::slowblink - turns on and off slowly (about twice a second):fastblink - turns on and off rapidly (about 7.5 times a second):slowwink - mostly on, but &quot;winks off&quot; once every second or so:heartbeat - a heartbeat patternCustomizing statesThe standard LED states are defined as @predefined_states near the top of lib/nerves_leds.ex. You can change or add to them using config.exs as follows:config :nerves_leds, states: [ fastblink: [ trigger: &quot;timer&quot;, delay_off: 40, delay_on: 30 ], blip: [ trigger: &quot;timer&quot;, delay_off: 1000, delay_on: 100 ]]See the Linux documentation on sys/class/leds to understand the meaning of trigger, delay, brightness, and other settings.","ref":"Nerves.Leds.html","title":"Nerves.Leds","type":"module"},{"doc":"Enumerate all the LEDs on this device. If the device has no LEDs or doesn't support the Linux LED interface, an empty list is returned.","ref":"Nerves.Leds.html#enumerate/0","title":"Nerves.Leds.enumerate/0","type":"function"},{"doc":"Set states of one or more LEDs by using their mapped name Nerves.Leds.set power: true, error: :fastblink","ref":"Nerves.Leds.html#set/1","title":"Nerves.Leds.set/1","type":"function"},{"doc":"Set the state of a single LEDNerves.Leds.set :power, true Nerves.Leds.set :backlight, brightness: 200Note that unlike set/1, this allows optionally directly naming the file of the led in /sys/class/leds by using a string name rather than an atom.Nerves.Leds.set &quot;led2&quot;, [ trigger: &quot;timer&quot;, delay_on: 1000, delay_off: 1000 ]","ref":"Nerves.Leds.html#set/2","title":"Nerves.Leds.set/2","type":"function"},{"doc":"Nerves.Leds Simple API to drive leds exposed by linux /sys/class/leds. Designed for use with Nerves, but works on any distribution of Linux with /sys/class/leds.","ref":"readme.html","title":"Nerves.Leds","type":"extras"},{"doc":"Add nerves_leds to your list of dependencies in mix.exs:def deps do [{:nerves_leds, &quot;~&gt; 0.8.1&quot;}] end","ref":"readme.html#installation","title":"Nerves.Leds - Installation","type":"extras"},{"doc":"Configure your LEDs mappings:# config/config.exs config :nerves_leds, names: [ error: &quot;led0&quot;, connect: &quot;led1&quot; ]Now, you can use predefined states in your app:alias Nerves.Leds Leds.set(connect: true) Leds.set(connect: :heartbeat) Leds.set(connect: false, error: :slowblink)You can also define your own states:# config/config.exs config :nerves_leds, states: [ fastblink: [ trigger: &quot;timer&quot;, delay_off: 40, delay_on: 30 ], blip: [ trigger: &quot;timer&quot;, delay_off: 1000, delay_on: 100 ]]For situations where the number of LEDs are not known at compile time, you can enumerate the LEDs:Leds.enumerate()","ref":"readme.html#configuration-usage","title":"Nerves.Leds - Configuration &amp; Usage","type":"extras"},{"doc":"See the documentation for the full description of the API and configuration.","ref":"readme.html#more-details","title":"Nerves.Leds - More Details","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Adds enumerate method for getting a list of available LEDs.","ref":"changelog.html#v0-8-1-2020-10-01","title":"Changelog - v0.8.1 (2020-10-01)","type":"extras"},{"doc":"Specifying string for LED name to set function now bypasses name mappingRemoved all compile-time config cacheing to avoid deps issuesNow raises ArgumentError for invalid statesAdded alternate single-LED API form set/2Simplified README","ref":"changelog.html#v0-8-0-2017-02-22","title":"Changelog - v0.8.0 (2017-02-22)","type":"extras"},{"doc":"This update reflects a number of changes that bring this module more in line with current Nerves and Elixir naming, coding, and license conventions, in preparation for pushing to hex. Unfortunately it changes the API, but hey, we're still &lt; 1.0, right?Breaking API ChangesRenamed project to nerves_leds (was nerves_io_led)Module is now Nerves.Leds (was Nerves.Led)Removed the alive functionality (can use oneshot trigger instead)Improved code style in places and fixed warningsImproved and fixed bugs in docsChanged LICENSE to Apache 2","ref":"changelog.html#v0-7-0-2016-06-21","title":"Changelog - v0.7.0 (2016-06-21)","type":"extras"},{"doc":"Breaking API Changesapp_name is now nerves_io_led for config.exschanged configuration options to avoid confusing 'map' terminologyconfig option name_map is now just namesconfig option state_map is now just states","ref":"changelog.html#v0-6-0-2015-10-04","title":"Changelog - v0.6.0 (2015-10-04)","type":"extras"},{"doc":"Move from Cellulose to Nerves ProjectScope as Nerves.IO.LedsAdd support for ExDocClean up README.mdAdd package support","ref":"changelog.html#v0-5-0-2015-10-01","title":"Changelog - v0.5.0 (2015-10-01)","type":"extras"}]